Heat transfer and pressure drop across tube bundles (ht.conv_tube_bank)
=======================================================================

.. automodule:: ht.conv_tube_bank
    :members:
    :undoc-members:
    :show-inheritance:
